@@ -78,7 +78,7 @@ msm_fit <- function(f,
     names(thecall) <- gsub("qdata", "data", names(thecall))
     names(thecall) <- gsub("f", "formula", names(thecall))
     m <- match(c("formula", "data", "weights", "offset"), names(thecall), 0L)
-    hasweights = ifelse("weights" %in% names(thecall), TRUE, FALSE)
+    hasweights = ("weights" %in% names(thecall))
     thecall <- thecall[c(1L, m)]
     thecall$drop.unused.levels <- TRUE
 
@@ -269,16 +269,17 @@ qgcomp.glm.noboot <- function(f,
   names(thecall) <- gsub("f", "formula", names(thecall))
   m <- match(c("formula", "data", "weights", "offset"), names(thecall), 0L)
   #m <- match(c("f", "data", "weights", "offset"), names(thecall), 0L)
-  hasweights = ifelse("weights" %in% names(thecall), TRUE, FALSE)
+  hasweights = ("weights" %in% names(thecall))
   thecall <- thecall[c(1L, m)]
   thecall$drop.unused.levels <- TRUE
-
+  thecall$na.action <- identity
+  
   thecall[[1L]] <- quote(stats::model.frame)
   thecalle <- eval(thecall, parent.frame()) # a model frame pulled in from the environment in which the function was called
   if(hasweights){
     data$weights <- as.vector(model.weights(thecalle))
-  } else data$weights = rep(1, nobs)
-
+  } else data$weights <- rep(1,nobs)
+  
 
   if (is.null(expnms)) {
 
@@ -373,13 +374,10 @@ qgcomp.glm.noboot <- function(f,
       hasintercept=hasintercept
     )
       if(fit$family$family=='gaussian'){
-        res$tstat <- tstat
-        res$df <- df
-        res$pval <- pval
+        res = .qgcomp_object_add(res, tstat=tstat, df=df, pval=pval)
       }
       if(fit$family$family %in% c('binomial', 'poisson')){
-        res$zstat <- tstat
-        res$pval <- pvalz
+        res = .qgcomp_object_add(res, zstat=tstat, pval=pvalz)
       }
     res
 }
@@ -594,7 +592,7 @@ qgcomp.glm.boot <- function(
     origcall <- thecall <- match.call(expand.dots = FALSE)
     names(thecall) <- gsub("f", "formula", names(thecall))
     m <- match(c("formula", "data", "weights", "offset"), names(thecall), 0L)
-    hasweights = ifelse("weights" %in% names(thecall), TRUE, FALSE)
+    hasweights = ("weights" %in% names(thecall))
     thecall <- thecall[c(1L, m)]
     thecall$drop.unused.levels <- TRUE
 
@@ -756,13 +754,10 @@ qgcomp.glm.boot <- function(
       hasintercept=hasintercept
     )
       if(msmfit$fit$family$family=='gaussian'){
-        res$tstat <- tstat
-        res$df <- df
-        res$pval <- pval
+         res = .qgcomp_object_add(res, tstat=tstat, df=df, pval=pval)
       }
       if(msmfit$fit$family$family %in% c('binomial', 'poisson')){
-        res$zstat <- tstat
-        res$pval <- pvalz
+         res = .qgcomp_object_add(res, zstat=tstat, pval=pvalz)
       }
     res
 }
