@@ -1,72 +1,200 @@
 # generics from other packages
 
 coef.qgcompfit <- function(object, ...){
-  #' @importFrom stats coef
-  #' @export
+  #' @exportS3Method stats::coef
   object$coef
 }
 
-coef.eefit <- function(object, ...){
-  #' @importFrom stats coef
-  #' @export
+coef.eefit <- function(object,...){
+  #' @exportS3Method stats::coef
   object$est
 }
 
 deviance.qgcompfit <- function(object, ...){
-  #' @importFrom stats deviance
-  #' @export
+  #' @exportS3Method stats::deviance
   object$fit$deviance
 }
 
 
 df.residual.qgcompfit <- function(object, ...){
-  #' @importFrom stats df.residual
-  #' @export
-  object$fit$df.residual
+  #' @exportS3Method stats::df.residual
+  df.residual(object$fit)
+}
+
+
+model.matrix.eeqgcompfit <- function(object, ...) {
+  #' @exportS3Method stats::model.matrix
+  object$fit$X
+}
+
+formula.eeqgcompfit <- function(x, ...) {
+  #' @exportS3Method stats::formula
+  x$call$f
 }
 
 vcov.qgcompfit <- function(object, ...){
-  #' @importFrom stats vcov
-  #' @export
+  #' @exportS3Method stats::vcov
   object$covmat.coef
 }
 
+vcov.eefit <- function(object,...){
+  #' @exportS3Method stats::vcov
+  # a fit or msmfit object from ee methods
+  object$vcov
+}
+
 AIC.qgcompfit <- function(object, ...){
-  #' @importFrom stats AIC
-  #' @export
+  #' @exportS3Method stats::AIC
   if(!is.null(object$bread)) stop("Calculation not available for estimating equation methods")
   AIC(object$fit)
 }
 
 BIC.qgcompfit <- function(object, ...){
-  #' @importFrom stats BIC
-  #' @export
+  #' @exportS3Method stats::BIC
   if(!is.null(object$bread)) stop("Calculation not available for estimating equation methods")
   BIC(object$fit)
 }
 
 logLik.qgcompfit <- function(object, ...){
-  #' @importFrom stats logLik
-  #' @export
+  #' @exportS3Method stats::logLik
   if(!is.null(object$bread)) stop("Calculation not available for estimating equation methods")
   logLik(object$fit)
 }
 
 anova.qgcompfit <- function(object, ...){
-  #' @importFrom stats anova
-  #' @export
+  #' @exportS3Method stats::anova
   if(!is.null(object$bread)) stop("Calculation not available for estimating equation methods")
   anova(object$fit)
 }
 
+anova.eeqgcompfit = function(object, ..., dispersion = NULL, test = NULL)
+{
+  #' @exportS3Method stats::anova
+  # based on geepack:::anova.geeglm
+  dotargs <- list(...)
+  named <- if (is.null(names(dotargs)))
+    rep(FALSE, length(dotargs))
+  else (names(dotargs) != "")
+  if (any(named))
+    warning("The following arguments to anova(..) are invalid and dropped: ",
+            paste(deparse(dotargs[named]), collapse = ", "))
+  dotargs <- dotargs[!named]
+  is.eefit <- unlist(lapply(dotargs, function(x) inherits(x, "eeqgcompfit")))
+  dotargs <- dotargs[is.eefit]
+  if (length(dotargs) > 0)
+    return(anova.eeqgcompfitlist(c(list(object), dotargs), dispersion = dispersion,
+                                 test = test))
+  else{
+    stop("Two model fits are needed")
+  }
+}
+
+anova.eeqgcompfitlist <- function(object, ..., dispersion = NULL, test = NULL)
+{
+  #' @exportS3Method stats::anova
+  responses <- as.character(lapply(object, function(x) {
+    deparse(formula(x)[[2]])
+  }))
+  sameresp <- responses == responses[1]
+  if (!all(sameresp)) {
+    object <- object[sameresp]
+    warning("Models with response ", deparse(responses[!sameresp]),
+            " removed because response differs from ", "model 1")
+  }
+  ns <- sapply(object, function(x) length(x$y.expected))
+  if (any(ns != ns[1]))
+    stop("models were not all fitted to the same size of dataset")
+  objects <- list(object, ...)
+  m1 <- objects[[1]][[1]]
+  if (length(objects[[1]]) > 1)
+    m2 <- objects[[1]][[2]]
+  else m2 <- NULL
+  value <- anovaqgcompgee(m1, m2)
+  return(value)
+}
+
+anovaqgcompgee <- function(m1, m2, ...) {
+  mm1 <- model.matrix(m1)
+  mm2 <- model.matrix(m2)
+  P1 <- mm1 %*% solve(t(mm1) %*% mm1) %*% t(mm1)
+  P2 <- mm2 %*% solve(t(mm2) %*% mm2) %*% t(mm2)
+  e2 <- mm2 - P1 %*% mm2
+  e1 <- mm1 - P2 %*% mm1
+  m2inm1 <- all(apply(e2, 2, var) < 1e-10)
+  m1inm2 <- all(apply(e1, 2, var) < 1e-10)
+  if (!any(c(m2inm1, m1inm2)))
+    cat("Models not nested\n")
+  else if (all(c(m2inm1, m1inm2)))
+    cat("Models are identical\n")
+  else {
+    if (m1inm2) {
+      tmp <- m1
+      m1 <- m2
+      m2 <- tmp
+    }
+    mm1 <- model.matrix(m1)
+    mm2 <- model.matrix(m2)
+    m1emm = m1$call$emmvar
+    m2emm = m2$call$emmvar
+    mf1 <- paste(paste(formula(m1))[c(2, 1, 3)], collapse = " ")
+    mf2 <- paste(paste(formula(m2))[c(2, 1, 3)], collapse = " ")
+    if (!any(is.null(m1$expnms))) mf1 = paste0(mf1, ", expnms: ", paste(m1$expnms, collapse=", "))
+    if (!any(is.null(m2$expnms))) mf2 = paste0(mf2, ", expnms: ", paste(m2$expnms, collapse=", "))
+    if (!any(is.null(m1emm))) mf1 = paste0(mf1, ", EMM: ", m1emm)
+    if (!any(is.null(m2emm))) mf2 = paste0(mf2, ", EMM: ", m2emm)
+    
+    
+    mm <- cbind(mm2, mm1)
+    qmm <- qr(mm)
+    qmmq <- qr.Q(qmm)
+    nymm1 <- as.data.frame(qmmq[, 1:qmm$rank])
+    colnames(nymm1) <- paste("parm", 1:ncol(nymm1), sep = ".")
+    nymm2 <- nymm1[, 1:ncol(mm2), drop = FALSE]
+    formula1 <- formula(paste(formula(m1)[[2]], formula(m1)[[1]],
+                              paste(c("-1", colnames(nymm1)), collapse = "+"),
+                              collapse = ""))
+    beta = coef(m1$fit)
+    vbeta = vcov(m1$fit)
+    df <- dim(mm1)[2] - dim(mm2)[2]
+    rbeta <- rep(1, length(beta))
+    rbeta[1:df] <- 0
+    beta0 <- rev(rbeta)
+    zeroidx <- beta0 == 0
+    V0 <- vbeta[zeroidx, zeroidx, drop = FALSE]
+    b0 <- beta[zeroidx]
+    #X2 <- as.numeric(t(b0) %*% ginv(V0) %*% b0) # MASS::ginv is not in the dependencies, reverting to solve
+    X2 <- as.numeric(t(b0) %*% solve(V0) %*% b0)
+    ev <- eigen(V0, only.values = TRUE)$values
+    df.real <- sum(ev > 1e-12)
+    topnote <- paste("Model 1", mf1, "\nModel 2", mf2)
+    title <- "Analysis of 'Wald statistic' Table\n"
+    table <- data.frame(Df = df.real, X2 = X2, p = 1 - pchisq(X2,
+                                                              df.real))
+    dimnames(table) <- list("1", c("Df", "X2", "P(>|Chi|)"))
+    val <- structure(table, heading = c(title, topnote),
+                     class = c("anova", "data.frame"))
+    return(val)
+  }
+}
+
 confint.qgcompfit <- function(object, parm, level=0.95, ...){
-  #' @importFrom stats confint
-  #' @export
+  #' @exportS3Method stats::confint
   est = coef(object)
   se = sqrt(diag(vcov(object)))
   cbind(lower = est+se*qnorm((1-level)/2), upper = est+se*qnorm(1-(1-level)/2))
 }
 
+confint.eefit <- function(object, parm, level=0.95, ...){
+  #' @exportS3Method stats::confint
+  est = coef(object)
+  std = sqrt(diag(vcov(object)))
+  critval = qnorm(c((1-level)/2, 1-(1-level)/2))
+  res = cbind(est + critval[1]*std, est + critval[2]*std)
+  colnames(res) <- paste(100*c((1-level)/2, 1-(1-level)/2), "%")
+  res
+}
+
+
 print.qgcompfit <- function(x, showweights=TRUE, ...){
   #' @title Default printing method for a qgcompfit object
   #' 
@@ -84,7 +212,7 @@ print.qgcompfit <- function(x, showweights=TRUE, ...){
   #' @param ... unused
   #' @seealso \code{\link[qgcomp]{qgcomp.glm.noboot}}, \code{\link[qgcomp]{qgcomp.glm.boot}}, and \code{\link[qgcomp]{qgcomp}}
   #' @concept variance mixtures
-  #' @export
+  #' @exportS3Method base::print
   #' @examples
   #' set.seed(50)
   #' dat <- data.frame(y=runif(50), x1=runif(50), x2=runif(50), z=runif(50))
@@ -156,8 +284,24 @@ print.qgcompfit <- function(x, showweights=TRUE, ...){
   invisible(x)
 }
 
+print.eefit <- function(x, ...){
+  #' @exportS3Method base::print
+  ci = confint(x, ...)
+  zp = ztest.eefit(x, ...)
+  pdat <- cbind(Estimate=coef(x), "Std. Error"=sqrt(diag(vcov(x))), "Lower CI"=ci[,1], "Upper CI"=ci[,2], "test"=zp[,1], "pval"=zp[,2])
+  testtype = "Z"
+  plab = ifelse(testtype=="Z", "Pr(>|z|)", "Pr(>|t|)")
+  colnames(pdat)[which(colnames(pdat)=="test")] = eval(paste(testtype, "value"))
+  colnames(pdat)[which(colnames(pdat)=="pval")] = eval(paste(plab))
+  rownames(pdat) <- names(coef(x))
+  printCoefmat(pdat,has.Pvalue=TRUE,tst.ind=5L,signif.stars=FALSE, cs.ind=1L:2)
+  invisible(x)
+}
+
+
+
 summary.qgcompfit <- function(object, ...){
-  #' @export
+  #' @exportS3Method base::summary
   fam <- object$fit$family$family
   if(inherits(object, "ziqgcompfit")){
     res = summaryZI(object)
@@ -207,7 +351,7 @@ summary.qgcompfit <- function(object, ...){
 }
 
 family.qgcompfit <- function(object, ...){
-  #' @export
+  #' @exportS3Method stats::family
   object$fit$family
 }
 
@@ -237,7 +381,7 @@ predict.qgcompfit <- function(object, expnms=NULL, newdata=NULL, type="response"
   #' returns a matrix giving the fitted values of each term in the model formula 
   #' on the linear predictor scale.
   #' @param ... arguments to predict.glm
-  #' @export
+  #' @exportS3Method stats::predict
   #' @examples
   #' set.seed(50)
   #' dat <- data.frame(y=runif(50), x1=runif(50), x2=runif(50), z=runif(50))
@@ -259,7 +403,7 @@ predict.qgcompfit <- function(object, expnms=NULL, newdata=NULL, type="response"
 }
 
 predict.eefit <- function(object, expnms=NULL, newdata=NULL, type=c("response", "link"), ...){
-  #' @export
+  #' @exportS3Method stats::predict
   if(is.null(object$X)){
     stop("IncludeX must be TRUE in the call to qgcomp.glm.ee")
   }
@@ -280,25 +424,7 @@ predict.eefit <- function(object, expnms=NULL, newdata=NULL, type=c("response",
   return(pred)
 }
 
-vcov.eefit <- function(object,...){
-  #' @export
-  object$vcov
-}
 
-coef.eefit <- function(object,...){
-  #' @export
-  object$est
-}
-
-confint.eefit <- function(object, parm, level=0.95, ...){
-  #' @export
-  est = coef(object)
-  std = sqrt(diag(vcov(object)))
-  critval = qnorm(c((1-level)/2, 1-(1-level)/2))
-  res = cbind(est + critval[1]*std, est + critval[2]*std)
-  colnames(res) <- paste(100*c((1-level)/2, 1-(1-level)/2), "%")
-  res
-}
 
 ztest.eefit <- function(object, parm, level=0.95, ...){
   est = coef(object)
@@ -311,17 +437,7 @@ ztest.eefit <- function(object, parm, level=0.95, ...){
   res
 }
 
-print.eefit <- function(x, ...){
-  #' @export
-  ci = confint(x, ...)
-  zp = ztest.eefit(x, ...)
-  pdat <- cbind(Estimate=coef(x), "Std. Error"=sqrt(diag(vcov(x))), "Lower CI"=ci[,1], "Upper CI"=ci[,2], "test"=zp[,1], "pval"=zp[,2])
-  testtype = "Z"
-  plab = ifelse(testtype=="Z", "Pr(>|z|)", "Pr(>|t|)")
-  colnames(pdat)[which(colnames(pdat)=="test")] = eval(paste(testtype, "value"))
-  colnames(pdat)[which(colnames(pdat)=="pval")] = eval(paste(plab))
-  rownames(pdat) <- names(coef(x))
-  printCoefmat(pdat,has.Pvalue=TRUE,tst.ind=5L,signif.stars=FALSE, cs.ind=1L:2)
-  invisible(x)
-}
+
+
+
 
