@@ -401,15 +401,16 @@ qgcomp.multinomial.noboot <- function(f,
   names(thecall) <- gsub("f", "formula", names(thecall))
   m <- match(c("formula", "data", "weights", "offset"), names(thecall), 0L)
   #m <- match(c("f", "data", "weights", "offset"), names(thecall), 0L)
-  hasweights = ifelse("weights" %in% names(thecall), TRUE, FALSE)
+  hasweights = ("weights" %in% names(thecall))
   thecall <- thecall[c(1L, m)]
   thecall$drop.unused.levels <- TRUE
+  thecall$na.action <- identity
   
   thecall[[1L]] <- quote(stats::model.frame)
   thecalle <- eval(thecall, parent.frame()) # a model frame pulled in from the environment in which the function was called
   if(hasweights){
     data$weights <- as.vector(model.weights(thecalle))
-  } else data$weights = rep(1, nobs)
+  } else data$weights <- rep(1,nobs)
   ####
   if (is.null(expnms)) {
     
@@ -595,7 +596,7 @@ msm_multinomial_fit <- function(f,
   names(thecall) <- gsub("qdata", "data", names(thecall))
   names(thecall) <- gsub("f", "formula", names(thecall))
   m <- match(c("formula", "data", "weights", "offset"), names(thecall), 0L)
-  hasweights = ifelse("weights" %in% names(thecall), TRUE, FALSE)
+  hasweights = ("weights" %in% names(thecall))
   thecall <- thecall[c(1L, m)]
   thecall$drop.unused.levels <- TRUE
   
@@ -870,7 +871,7 @@ qgcomp.multinomial.boot <- function(
   origcall <- thecall <- match.call(expand.dots = FALSE)
   names(thecall) <- gsub("f", "formula", names(thecall))
   m <- match(c("formula", "data", "weights", "offset"), names(thecall), 0L)
-  hasweights = ifelse("weights" %in% names(thecall), TRUE, FALSE)
+  hasweights = ("weights" %in% names(thecall))
   thecall <- thecall[c(1L, m)]
   thecall$drop.unused.levels <- TRUE
   
